#!/bin/sh
#
# Utilities for installer use.
#
# Iwo

# Append a new line to file
# $1 = filename, $2 = line
config_append () {
	#echo "config_append $1 $2"
	echo -e -n "$2" >> "$1"
}

# Insert a new line before line $2 into file
# $1 = filename, $2 = lineoffset , $3 = line
config_insert () {
	LN=1
	rm -f $1.new
	oldsep="$IFS"
	IFS=""
	while read line; do
		if [ "$LN" = "$2" ]; then
			echo "$3" >>$1.new
		fi
		echo "$line" >>$1.new
		LN=`expr $LN + 1`
	done < "$1"
	
	if ls -l $1 | grep "^-r.x" >/dev/null ; then
		chmod a+x $1.new
	fi
	
	mv $1.new $1
	IFS="$oldsep"
}

# Replace a line matching regexp with new line
# $1 = filename, $2 = regexp, $3 = newline
# Outputs the matched line (for save & replace)
config_replace() {
	file="$1"
	regexp="$2"
	newline="$3"

	awk '{
		if (match($0,MATCH)!=0)
			$0=REPLACE
		print
	}' MATCH="$regexp" REPLACE="$newline" "$file" >"$file.new"

	mv $file.new $file
}

# Deletes a line from a file
# $1 = file, $2 = regexp
config_delete () {
	grep -v "$2" "$1" > "$1.tmp"
	if ls -l $1 | grep "^-r.x" >/dev/null ; then
		chmod a+x $1.tmp
	fi
	mv "$1.tmp" "$1"
}

# Inserts a menu/link into the webinterface (revision dependent)
# $1 = URL, $2 = name
menu_insert() {
	if [ -L /www/linkFiles ]; then
		MFILES="/www/CDCSFiles/menu.htm /www/NTCFiles/menu.htm"
	else
		MFILES="/www/menu.htm"
	fi
#	MFILES="menu.htm"; # Testing only
	for f in $MFILES; do
		TMP="$f.temp"; rm -f "$TMP"
		echo "Scanning $f"
		# Finding the OptionMenu entry, then inserting before end of function
		OIFS=$IFS
		IFS=
		STATE=0
		cat $f | while read line; do
			if [ $STATE -eq 0 ]; then
				# Searching for beginning of menu
				if echo "$line" | grep -q '<ul style='; then
					STATE=1
				fi
			else
				# Searching for end of menu
				if echo "$line" | grep -q 'id="MenuID">'; then
					STATE=0
					# Insert new menu
					echo "Inserting menu $2"
					echo "            <li><a href=\"$1\" target=\"main\">$2</a></li>" >>"$TMP"
				fi
			fi
			echo "$line" >>"$TMP"
		done
		IFS=$OIFS
		mv "$TMP" "$f"
	done
}

# Removes a menu/link from the webinterface
# $1 = URL, $2 = name
menu_delete() {
	if [ -L /www/linkFiles ]; then
		MFILES="/www/CDCSFiles/menu.htm /www/NTCFiles/menu.htm"
	else
		MFILES="/www/menu.htm"
	fi
#	MFILES="menu.htm"; # testing only
	for f in $MFILES; do
		TMP="$f.temp"
		echo "Removing menu $2 from $f"
		OIFS=$IFS
		IFS=
		STATE=0
		cat $f | while read line; do
			if echo "$line" | grep -v -q "<li><a href=\"$1\" target=\"main\">$2</a></li>"; then
				echo "$line" >>"$TMP"
			fi
		done
		IFS=$OIFS
		mv "$TMP" "$f"
	done
}

# Testing only
#menu_insert "/cgi-bin/aarghh.cgi" "Aargh"
#menu_delete "/cgi-bin/aarghh.cgi" "Aargh"
